appconfig

package
v0.0.0-...-64228a9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 20, 2026 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Config

type Config struct {
	Profile          *string
	URL              *string
	Region           string
	AvailableRegions []string
	StarredRegions   []string
	Client           *dynamodb.Client
	MaxTables        int

	// credentials
	MFACredentialCB func() (string, error)
	MFACredentialC  chan<- CredentialsResponse
}

type CredentialsRequest

type CredentialsRequest struct{}

type CredentialsResponse

type CredentialsResponse struct {
	Token string
	Error error
}

Directories

Path Synopsis
aws
package config defines the app configuration file and tooling for config i/o
package config defines the app configuration file and tooling for config i/o
ui
internal/adapters/dynamodb
Adapter parses dynamodb connector responses for UI display purposes, including JSON/YAML and styling
Adapter parses dynamodb connector responses for UI display purposes, including JSON/YAML and styling
internal/components/checkbox_list
package checkboxlist collects generic resources to be used and composed in a list that requires checkboxable items
package checkboxlist collects generic resources to be used and composed in a list that requires checkboxable items
internal/components/headed_list
package headedlist collects generic resources to be used and composed in a list that requires items to be headed
package headedlist collects generic resources to be used and composed in a list that requires items to be headed
internal/components/regular_list
package regularlist collects generic resources to be used and composed in a list that requires only basic functionality for its items
package regularlist collects generic resources to be used and composed in a list that requires only basic functionality for its items
internal/components/search
credits go to charm.land/bubbles/v2/list/list.go
credits go to charm.land/bubbles/v2/list/list.go
internal/components/table
Package table is a customized implementation of the simple table implementation at "charm.land/bubbles/v2/table".
Package table is a customized implementation of the simple table implementation at "charm.land/bubbles/v2/table".
internal/views/util/keymaps
package keymaps defines resources for sharing additional key-maps across different app layers
package keymaps defines resources for sharing additional key-maps across different app layers
package util defines various generic go utility functions
package util defines various generic go utility functions

Jump to