ui

package
v0.0.0-...-64228a9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 20, 2026 License: MIT Imports: 18 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DialogCloseKeymapFrom

func DialogCloseKeymapFrom(keymap key.Binding) key.Binding

DialogCloseKeymapFrom returns a keymap that is intended to close a dialog. It includes the first key mapped to the dialog to allow for closing it too. This ensures that fluid dialog UX.

Types

type Dialog

type Dialog int

type KeyMap

type KeyMap struct {
	ForceQuit key.Binding
	Help      key.Binding
}

KeyMap defines keybindings. It satisfies to the help.KeyMap interface, which is used to render the help menu.

func DefaultKeyMap

func DefaultKeyMap() KeyMap

DefaultKeyMap returns a default set of keybindings.

func (*KeyMap) FullHelp

func (km *KeyMap) FullHelp() [][]key.Binding

FullHelp implements the KeyMap interface.

func (*KeyMap) ShortHelp

func (km *KeyMap) ShortHelp() []key.Binding

ShortHelp implements the KeyMap interface.

type Model

type Model struct {
	QueryMode messages.ItemsQueryMode

	KeyMap KeyMap

	// help
	Help help.Model
	// contains filtered or unexported fields
}

func NewModel

func NewModel(ctx context.Context, cfg appconfig.Config, opts ...Option) Model

func (Model) CloseMFADialog

func (m Model) CloseMFADialog() (Model, tea.Cmd)

TODO: now assuming no dialog can be open prior to MFA call; fallback to previous dialog if appliccable!

func (Model) HandleExpiredError

func (m Model) HandleExpiredError(msg messages.NotificationExpired) (Model, tea.Cmd)

func (Model) Init

func (m Model) Init() tea.Cmd

func (Model) OpenMFADialog

func (m Model) OpenMFADialog() (Model, tea.Cmd)

TODO: now assuming no dialog can be open prior to MFA call; ensure existing dialogs are closed first!

func (Model) SignalOpenHelpDialog

func (m Model) SignalOpenHelpDialog() tea.Cmd

func (Model) SwitchQueryMode

func (m Model) SwitchQueryMode(msg messages.SwitchQueryMode) (Model, tea.Cmd)

func (Model) ToggleColumnSortingDialog

func (m Model) ToggleColumnSortingDialog() (Model, tea.Cmd)

func (Model) ToggleColumnsDialog

func (m Model) ToggleColumnsDialog() (Model, tea.Cmd)

func (Model) ToggleCopyDialog

func (m Model) ToggleCopyDialog() (Model, tea.Cmd)

func (Model) ToggleHelpDialog

func (m Model) ToggleHelpDialog() (Model, tea.Cmd)

func (Model) ToggleNotificationDialog

func (m Model) ToggleNotificationDialog(msg messages.ToggleNotificationDialog) (Model, tea.Cmd)

func (Model) ToggleQueryParametersDialog

func (m Model) ToggleQueryParametersDialog() (Model, tea.Cmd)

func (Model) ToggleRegionsDialog

func (m Model) ToggleRegionsDialog() (Model, tea.Cmd)

func (Model) ToggleScanParametersDialog

func (m Model) ToggleScanParametersDialog() (Model, tea.Cmd)

func (Model) Update

func (m Model) Update(msg tea.Msg) (tea.Model, tea.Cmd)

update handles the message and proceeds to forward it to the model's children

func (Model) View

func (m Model) View() tea.View

type Option

type Option func(*options)

func WithInitialErrorNotification

func WithInitialErrorNotification(err error) Option

type View

type View int

Directories

Path Synopsis
internal
adapters/dynamodb
Adapter parses dynamodb connector responses for UI display purposes, including JSON/YAML and styling
Adapter parses dynamodb connector responses for UI display purposes, including JSON/YAML and styling
components/checkbox_list
package checkboxlist collects generic resources to be used and composed in a list that requires checkboxable items
package checkboxlist collects generic resources to be used and composed in a list that requires checkboxable items
components/headed_list
package headedlist collects generic resources to be used and composed in a list that requires items to be headed
package headedlist collects generic resources to be used and composed in a list that requires items to be headed
components/regular_list
package regularlist collects generic resources to be used and composed in a list that requires only basic functionality for its items
package regularlist collects generic resources to be used and composed in a list that requires only basic functionality for its items
components/search
credits go to charm.land/bubbles/v2/list/list.go
credits go to charm.land/bubbles/v2/list/list.go
components/table
Package table is a customized implementation of the simple table implementation at "charm.land/bubbles/v2/table".
Package table is a customized implementation of the simple table implementation at "charm.land/bubbles/v2/table".
views/util/keymaps
package keymaps defines resources for sharing additional key-maps across different app layers
package keymaps defines resources for sharing additional key-maps across different app layers

Jump to