Documentation
¶
Index ¶
- func DialogCloseKeymapFrom(keymap key.Binding) key.Binding
- type Dialog
- type KeyMap
- type Model
- func (m Model) CloseMFADialog() (Model, tea.Cmd)
- func (m Model) HandleExpiredError(msg messages.NotificationExpired) (Model, tea.Cmd)
- func (m Model) Init() tea.Cmd
- func (m Model) OpenMFADialog() (Model, tea.Cmd)
- func (m Model) SignalOpenHelpDialog() tea.Cmd
- func (m Model) SwitchQueryMode(msg messages.SwitchQueryMode) (Model, tea.Cmd)
- func (m Model) ToggleColumnSortingDialog() (Model, tea.Cmd)
- func (m Model) ToggleColumnsDialog() (Model, tea.Cmd)
- func (m Model) ToggleCopyDialog() (Model, tea.Cmd)
- func (m Model) ToggleHelpDialog() (Model, tea.Cmd)
- func (m Model) ToggleNotificationDialog(msg messages.ToggleNotificationDialog) (Model, tea.Cmd)
- func (m Model) ToggleQueryParametersDialog() (Model, tea.Cmd)
- func (m Model) ToggleRegionsDialog() (Model, tea.Cmd)
- func (m Model) ToggleScanParametersDialog() (Model, tea.Cmd)
- func (m Model) Update(msg tea.Msg) (tea.Model, tea.Cmd)
- func (m Model) View() tea.View
- type Option
- type View
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type KeyMap ¶
KeyMap defines keybindings. It satisfies to the help.KeyMap interface, which is used to render the help menu.
func DefaultKeyMap ¶
func DefaultKeyMap() KeyMap
DefaultKeyMap returns a default set of keybindings.
type Model ¶
type Model struct {
QueryMode messages.ItemsQueryMode
KeyMap KeyMap
// help
Help help.Model
// contains filtered or unexported fields
}
func (Model) CloseMFADialog ¶
TODO: now assuming no dialog can be open prior to MFA call; fallback to previous dialog if appliccable!
func (Model) HandleExpiredError ¶
func (Model) OpenMFADialog ¶
TODO: now assuming no dialog can be open prior to MFA call; ensure existing dialogs are closed first!
func (Model) SignalOpenHelpDialog ¶
func (Model) SwitchQueryMode ¶
func (Model) ToggleColumnSortingDialog ¶
func (Model) ToggleNotificationDialog ¶
func (Model) ToggleQueryParametersDialog ¶
func (Model) ToggleScanParametersDialog ¶
Directories
¶
| Path | Synopsis |
|---|---|
|
internal
|
|
|
adapters/dynamodb
Adapter parses dynamodb connector responses for UI display purposes, including JSON/YAML and styling
|
Adapter parses dynamodb connector responses for UI display purposes, including JSON/YAML and styling |
|
components/checkbox_list
package checkboxlist collects generic resources to be used and composed in a list that requires checkboxable items
|
package checkboxlist collects generic resources to be used and composed in a list that requires checkboxable items |
|
components/headed_list
package headedlist collects generic resources to be used and composed in a list that requires items to be headed
|
package headedlist collects generic resources to be used and composed in a list that requires items to be headed |
|
components/regular_list
package regularlist collects generic resources to be used and composed in a list that requires only basic functionality for its items
|
package regularlist collects generic resources to be used and composed in a list that requires only basic functionality for its items |
|
components/search
credits go to charm.land/bubbles/v2/list/list.go
|
credits go to charm.land/bubbles/v2/list/list.go |
|
components/table
Package table is a customized implementation of the simple table implementation at "charm.land/bubbles/v2/table".
|
Package table is a customized implementation of the simple table implementation at "charm.land/bubbles/v2/table". |
|
views/util/keymaps
package keymaps defines resources for sharing additional key-maps across different app layers
|
package keymaps defines resources for sharing additional key-maps across different app layers |
Click to show internal directories.
Click to hide internal directories.